Learn R Programming

ClimMobTools (version 0.2-7)

getDataCM: Get ClimMob data

Description

Fetch the trial data from a ClimMob project using an API key

Usage

getDataCM(key = NULL, project = NULL, tidynames = FALSE,
  pivot.wider = FALSE, ...)

Arguments

key

a character for the ClimMob user API key

project

a character for the project id

tidynames

logical, if TRUE suppress ODK strings

pivot.wider

logical, if TRUE return a wider object, each observer is a row

...

additional arguments passed to methods

Value

A data frame with the project data

id

the participant's package id

moment

the data collection moment

variable

the variable name

value

the value for each variable

See Also

getProjectsCM

Examples

Run this code
# NOT RUN {
# This function will not work without an API key  
# the user API key can be obtained once a free ClimMob account 
# is created via https://climmob.net/climmob3/

my_key <- "add_your_key"
my_project <- "my_climmob_project"

data <- getDataCM(key = my_key, project = my_project)

# }
# NOT RUN {
# }

Run the code above in your browser using DataLab